@@ -8,9 +8,8 @@
 #' indicates DIF if the respective parameter is selected (estimated to be unequal zero). 
 #' Parameter selection is done using a lasso-type penalization term.
 #' 
-#' 
+"_PACKAGE"
 #' @name GPCMlasso-package
-#' @docType package
 #' @author Gunther Schauberger\cr \email{gunther.schauberger@@tum.de}
 #' @references Schauberger, Gunther and Mair, Patrick (2019): A Regularization Approach for the Detection of Differential 
 #' Item Functioning in Generalized Partial Credit Models, \emph{Behavior Research Methods}, \url{https://link.springer.com/article/10.3758/s13428-019-01224-2}
