@@ -147,7 +147,9 @@ GPCMlasso <- function(formula, data, DSF = FALSE,
   design_list <- design_GPCMlasso(formula = formula, data = data, 
                                   Y = Y, RSM = RSM, GPCM = GPCM, 
                                   DSF = DSF, all.dummies = control$all.dummies,
-                                  main.effects = main.effects)
+                                  main.effects = main.effects,
+                                  penalize.main.effects = control$penalize.main.effects,
+                                  fuse.per.variable = control$fuse.per.variable)
 
   
   ## if no covariates are used, we don't need lambda or adaptive
@@ -180,7 +182,7 @@ GPCMlasso <- function(formula, data, DSF = FALSE,
   if(is.null(control$lambda)){
     control$lambda <- fit$lambda
   }
-  
+# browser()
   ## extract coefficients
   coefficients <-  fit$coefficients
   
@@ -199,7 +201,7 @@ GPCMlasso <- function(formula, data, DSF = FALSE,
   if(cv){
     cv_error <- fit_cv_GPCMlasso(model, design_list, 
                                   control, score_fun,
-                                  loglik_fun, log_score_fun, Y)
+                                  loglik_fun, log_score_fun, Y, main.effects)
   }else{
     cv_error <- NULL
   }
