@@ -5,7 +5,9 @@ createResponse <- function(Y){
 }
 
 design_GPCMlasso <- function(formula = formula, Y=Y, data = data, RSM = RSM, 
-                             GPCM = GPCM, DSF = DSF, all.dummies = TRUE, main.effects = main.effects){
+                             GPCM = GPCM, DSF = DSF, all.dummies = TRUE, 
+                             main.effects = main.effects, penalize.main.effects,
+                             fuse.per.variable){
 
   ## extract covariates
   if(all.dummies){
@@ -84,7 +86,8 @@ design_GPCMlasso <- function(formula = formula, Y=Y, data = data, RSM = RSM,
     designX <- -get_designX(X, DSF, m, I, q, n)
     
     ## create penalization matrix
-    acoefs <- get_acoefs(RSM, DSF, m, I, q, n_sigma)
+    acoefs <- get_acoefs(RSM, DSF, m, I, q, n_sigma, main.effects,
+                         penalize.main.effects, fuse.per.variable)
 
         ## update number of parameters to be optimized
     px <- px + ncol(designX)
@@ -97,11 +100,11 @@ design_GPCMlasso <- function(formula = formula, Y=Y, data = data, RSM = RSM,
   if(main.effects){
     design.main <- matrix(rep(X, each = sum(q)),ncol = ncol(X))
     designX <- cbind(design.main, designX)
-    acoefs <- rbind(matrix(0, ncol = ncol(acoefs), nrow = ncol(design.main)), acoefs)
+    #acoefs <- rbind(matrix(0, ncol = ncol(acoefs), nrow = ncol(design.main)), acoefs)
     px <- px + ncol(X)
   }
   
- 
+
   ret.list <- list(q = q, I = I, m = m, px = px, n = n, response = response,
                    design = design, designX = designX, sd.vec = sd.vec,
                    acoefs = acoefs, n_sigma = n_sigma, x.names = x.names,
