@@ -1,7 +1,7 @@
 fit_GPCMlasso <- function(model = model, loglik_fun = loglikPCMlasso, score_fun = scorePCMlasso,
                           log_score_fun = loglikscorePCMlasso,
                           design_list = design_list, 
-                          control = control, start = NULL, scale_fac = 1, main.effects = TRUE){
+                          control = control, start = NULL, scale_fac = 1, main.effects = main.effects){
 
   ## start with-expression to use everything from design_list and control
   with(c(design_list,control),{
@@ -24,7 +24,8 @@ fit_GPCMlasso <- function(model = model, loglik_fun = loglikPCMlasso, score_fun
                       GHweights, GHnodes, acoefs, lambda2, cvalue, n_sigma,
                       l.bound, trace, log.lambda, weight.penalties, scale_fac, ada.lambda,
                       lambda.min, ada.power, cores, null_thresh, DSF, gradtol, iterlim, steptol,
-                      main.effects = main.effects)
+                      main.effects = main.effects, penalize.main.effects = penalize.main.effects,
+                      ctrl.gpcm = ctrl.gpcm)
   
   weight <- help_me$weight
   alpha.start <- help_me$alpha.start
@@ -35,7 +36,7 @@ fit_GPCMlasso <- function(model = model, loglik_fun = loglikPCMlasso, score_fun
   ## start estimation along lambda
   coef.final <- coef.orig <- matrix(0, nrow=length(lambda), ncol = px)
   logLik <- df <- c()
-  
+
   ########################
   for(l in seq_along(lambda)){
     if(trace){
@@ -53,6 +54,7 @@ suppressWarnings(
     coefs.l <- try(m.opt$estimate)
 
     if(inherits(m.opt, "try-error")){
+      browser()
         m.opt <- try(nlminb(start = alpha.start, objective = loglik_fun, gradient = score_fun,
                Q = Q, q = q, I = I, n = n, Y = response, X = design, Z = designX, px = px,
                GHweights = GHweights, GHnodes = GHnodes,
@@ -63,19 +65,32 @@ suppressWarnings(
         coefs.l <- m.opt$par
     }
     alpha.start <- coefs.l
-      
+      # browser()
     coefs.l[abs(coefs.l)<null_thresh & rowSums(abs(acoefs))!=0] <- 0
       
     coef.orig[l,] <- coefs.l
     
       coefs.l <- round(coefs.l, precision)
+      
+      n.pen.help <- m*I
+      if(main.effects & penalize.main.effects){
+        n.pen.help <- n.pen.help+m
+        }
 
-      if(sum(colSums(abs(acoefs))!=0)==m*I){
+      if(sum(colSums(abs(acoefs))!=0)==n.pen.help){
         df.l <- sum(abs(t(acoefs)%*%coefs.l)!=0)
       }else{
+        if(fuse.per.variable){
+          ## needs to be modified
+          df.l <- 10
+        }else{
         df.l <- 0
         coefs.pen <- coefs.l[rowSums(abs(acoefs))!=0]
         start.coefs <- 1
+        if(main.effects & penalize.main.effects){
+          start.coefs <- m+1
+          df.l <- df.l + sum(coefs.pen[1:m]!=0)
+        }
         for(i in 1:I){
           coefs.i <- coefs.pen[start.coefs:(start.coefs-1+q[i]*m)]
           gamma.index <- matrix(1:(q[i]*m),nrow=m)
@@ -86,7 +101,9 @@ suppressWarnings(
           start.coefs <- q[i]*m+start.coefs
         }
 
+        }
       }
+      
       df.l <- df.l + sum(rowSums(abs(acoefs))==0)
       
       logLik.l <- -loglik_fun(coefs.l, Q = Q, q = q, I = I, n = n,
