@@ -120,7 +120,7 @@ predict.GPCMlasso <- function(object, coefs = NULL,
     designX <- object$design_list$designX
   }
 
-    
+     # browser()
     RSM <- GPCM <- FALSE
     if(object$model %in% c("GRSM","RSM")){
       RSM <- TRUE
@@ -139,7 +139,15 @@ predict.GPCMlasso <- function(object, coefs = NULL,
     
     theta <- trait.posterior(object, coefs, cores = object$control$cores)
 
+    ### old version not taking into account beta_i
     return_list <- rep(theta,each=sum(q))+lin.pred
+    
+    ## new version with beta_i
+    beta_i <- coefs[(length(coefs)-n_sigma+1):length(coefs)]
+    if(!GPCM){
+      beta_i <- rep(beta_i,I)
+    }
+    return_list <- rep(rep(beta_i,q),n) * (rep(theta,each=sum(q))+lin.pred)
     return_list <- split(return_list, rep(rep(1:I,q),n)+(rep(1:n,each=sum(q))-1)*I)
     
     if(type=="response"){
